@@ -23,10 +23,14 @@ from .expt import Expt  # noqa
 from .gee import GEE  # noqa
 from .ghmin import GHMin  # noqa
 from .gtminpat import GTMinPat  # noqa
+from .hidr import Hidr  # noqa
 from .itaipu import Itaipu  # noqa
 from .manutt import ManutT  # noqa
 from .modif import Modif  # noqa
+from .newavetim import NewaveTim  # noqa
 from .parp import PARp  # noqa
+from .parpvaz import PARpvaz  # noqa
+from .parpeol import PARpeol  # noqa
 from .patamar import Patamar  # noqa
 from .penalid import Penalid  # noqa
 from .perda import Perda  # noqa
@@ -38,5 +42,11 @@ from .shist import Shist  # noqa
 from .sistema import Sistema  # noqa
 from .tecno import Tecno  # noqa
 from .term import Term  # noqa
+from .vazoes import Vazoes  # noqa
 from .vazpast import VazPast  # noqa
 from .eolicacadastro import EolicaCadastro  # noqa
+from .eolicaconfiguracao import EolicaConfiguracao  # noqa
+from .eolicafte import EolicaFTE  # noqa
+from .eolicageracao import EolicaGeracao  # noqa
+from .eolicahistorico import EolicaHistorico  # noqa
+from .eolicasubmercado import EolicaSubmercado  # noqa
