@@ -10,19 +10,19 @@ def test_atributos_encontrados_geol():
     m: MagicMock = mock_open(read_data="".join(MockGeol))
     with patch("builtins.open", m):
         n = Geol.le_arquivo("")
-        assert n.pee is not None
+        assert n.usina is not None
         # assert n.pee == "cluster_NE_1"
-        assert n.geracao is not None
-        assert n.geracao.iloc[0, 0] == 2021
-        assert n.geracao.iloc[-1, -1] == 2652.7
+        assert n.valores is not None
+        assert n.valores.iloc[0, 0] == 2021
+        assert n.valores.iloc[-1, -1] == 2652.7
 
 
 def test_atributos_nao_encontrados_geol():
     m: MagicMock = mock_open(read_data="")
     with patch("builtins.open", m):
         n = Geol.le_arquivo("")
-        assert n.pee is None
-        assert n.geracao is None
+        assert n.usina is None
+        assert n.valores is None
 
 
 def test_eq_geol():
